@@ -1,6 +1,6 @@
 package XML::LibXML::Cache::Base;
 {
-  $XML::LibXML::Cache::Base::VERSION = '0.11';
+  $XML::LibXML::Cache::Base::VERSION = '0.12';
 }
 use strict;
 
@@ -22,17 +22,29 @@ my $deps_found;
 sub new {
     my $class = shift;
 
-    my $self = { cache => {} };
+    my $self = {
+        cache => {},
+        hits  => 0,
+    };
 
     return bless($self, $class);
 }
 
+sub cache_hits {
+    my $self = shift;
+
+    return $self->{hits};
+}
+
 sub _cache_lookup {
     my ($self, $filename, $get_item) = @_;
 
     my $item = $self->_cache_read($filename);
 
-    return $item if $item;
+    if ($item) {
+        ++$self->{hits};
+        return $item;
+    }
 
     $deps_found = {};
 
@@ -123,7 +135,7 @@ XML::LibXML::Cache::Base - Base class for XML::LibXML caches
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
@@ -133,6 +145,14 @@ Base class for the document and style sheet caches.
 
 =head2 new
 
+Only used by subclasses.
+
+=head2 cache_hits
+
+    my $hits = $cache->cache_hits;
+
+Return the number of cache hits.
+
 =head1 AUTHOR
 
 Nick Wellnhofer <wellnhofer@aevum.de>
